# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.0] - 2019-10-21

### Added

- Initial project structure, tooling, and contributing guidelines

[Unreleased]: https://github.com/bhrutledge/pytest-quarantine/compare/0.0.0...HEAD
[0.0.0]: https://github.com/bhrutledge/pytest-quarantine/releases/tag/0.0.0
